#
# spec file for package jupyter
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define plainpython python
Name:           jupyter
Version:        1.1.1
Release:        1.2
Summary:        Metapackage to install all the Jupyter components in one go
License:        BSD-3-Clause
Group:          Development/Languages/Python
URL:            https://jupyter.org/
Source0:        https://files.pythonhosted.org/packages/source/j/jupyter/jupyter-%{version}.tar.gz
Source99:       jupyter.rpmlintrc
BuildRequires:  %{python_module ipykernel}
BuildRequires:  %{python_module ipywidgets}
BuildRequires:  %{python_module jupyter-console}
BuildRequires:  %{python_module jupyterlab}
BuildRequires:  %{python_module nbconvert}
BuildRequires:  %{python_module notebook}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildRequires:  unzip
Requires:       python-ipykernel
Requires:       python-ipywidgets
Requires:       python-jupyter-console
Requires:       python-jupyterlab
Requires:       python-nbconvert
Requires:       python-notebook
Suggests:       python-qtconsole
Requires:       %plainpython(abi) = %{python_version}
%if "%{python_flavor}" == "python3" || "%{python_provides}" == "python3"
Provides:       jupyter = %{version}-%{release}
Obsoletes:      jupyter < %{version}-%{release}
%endif
BuildArch:      noarch
%python_subpackages

%description
Jupyter is an environment for interactive computing in multiple languages.
It includes a console, a browser-based notebook format, and support for
dozens of languages through the use of language-specific kernels.

This is an empty metapackage for user convenience, only expressing
dependencies on multiple Jupyter packages. jupyter should not be used
as a dependency for any packages.

For more efficient installation of what you need, all Jupyter components
installed by pip install jupyter can be installed separately. For example:
  - %{python_flavor}-notebook - Jupyter Notebook
  - %{python_flavor}-jupyterlab - JupyterLab (added to metapackage v1.1)
  - %{python_flavor}-ipython - IPython (terminal)
  - %{python_flavor}-ipykernel - IPython Kernel for Jupyter
  - %{python_flavor}-jupyter-console - terminal Jupyter client
  - %{python_flavor}-nbconvert - convert notebooks between formats
  - %{python_flavor}-ipywidgets - interactive widgets package for IPython

No longer included as hard dependency, but still supported:

  - %{python_flavor}-qtconsole - Qt Console (removed in metapackage v1.1)

%prep
%setup -q -n jupyter-%{version}

%build
%pyproject_wheel

%install
%pyproject_install

%files %python_files
%license LICENSE
%doc README.md SECURITY.md
%{python_sitelib}/jupyter-%{version}.dist-info

%changelog
* Wed Nov 27 2024 Ben Greiner <code@bnavigator.de>
- Update to new metapackage 1.1.1
- Drop doc package: No longer packaged at readthedocs
* Tue Mar  5 2024 Ben Greiner <code@bnavigator.de>
- Skip python39: no longer supported since ipython 8.19
* Mon May 22 2023 Jiri Srain <jsrain@suse.com>
- refresh also the jupyter.zip from upstream URL
* Mon May 22 2023 Jiri Srain <jsrain@suse.com>
- refresh the jupyter.pdf from upstream URL
* Fri May  5 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Add _multibuild to define 2nd spec file as additional flavor.
  Eliminates the need for source package links in OBS.
* Thu Mar 30 2023 Ben Greiner <code@bnavigator.de>
- remove explicit jupyter-client dep in order ot avoid resolver
  conflicts with python-notebook
* Fri Jan  7 2022 Ben Greiner <code@bnavigator.de>
- Skip python2: There is no python2-qtconsole
* Sun Nov 14 2021 Ben Greiner <code@bnavigator.de>
- Require python(abi) in order to silence rpmlint
* Sun Jan 31 2021 Ben Greiner <code@bnavigator.de>
- Back to singlespec for multiple python flavors. The primary
  python3 flavor provides the "jupyter" package.
- Do what the description advertises and what upstream does:
  Require the specified packages
- Update documentation files: jupyter.pdf and jupyter.zip
* Tue Nov 12 2019 Todd R <toddrme2178@gmail.com>
- jupyter_core has been renamed to jupyter-core
- jupyter_client has been renamed to jupyter-client
* Thu Apr 25 2019 Todd R <toddrme2178@gmail.com>
- Rename to to match jupyter package naming guidelines.
* Tue Feb 13 2018 toddrme2178@gmail.com
- Update url
* Wed Apr 26 2017 toddrme2178@gmail.com
- Implement single-spec version.
* Fri Apr  7 2017 toddrme2178@gmail.com
- Remove jupyter.py since it is now provided by python3-jupyter_core.
- Clean up documentation building.
* Thu Mar 16 2017 jmatejek@suse.com
- do not Recommend jupyter_nbconvert (which pulls in texlive)
* Wed Oct 21 2015 toddrme2178@gmail.com
- No longer provide or obsolete IPython.
  This is provided and obsoleted by python-jupyter_ipython.
* Mon Oct  5 2015 toddrme2178@gmail.com
- Build documentation
* Fri Aug 28 2015 toddrme2178@gmail.com
- Fix provides again.
* Fri Aug 28 2015 toddrme2178@gmail.com
- Fix provides and obsoletes
* Fri Aug 28 2015 toddrme2178@gmail.com
- Initial version
